@@ -6,7 +6,7 @@ use warnings;
 use Scalar::Util 'blessed';
 use Carp;
 
-our $VERSION = '1.1';
+our $VERSION = '1.2';
 
 sub new {
 	my ($class,$data,$callback)=@_;
@@ -97,7 +97,7 @@ sub get {
 
 	# check if last element is reached
 	if ($rest) {
-		if ( ref $value eq 'HASH' ) {
+		if ( ref $value eq 'HASH' || blessed $value ) {
 			$value=$self->get($rest,$value);
 		} else {
 			$self->{callback}->{retrieve_key_from_non_hash}->($data, $key, $index, $value, $rest);
